<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Http\Resources\API\BimCombineResource;
use App\Libraries\BIM\Glendale\Glendale;
use App\Models\BimCombine;
use App\Models\Library;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class BimController extends Controller
{
    //模型多视图信息
    public function multipleViews(Request $request, Glendale $glendale)
    {
        $lightweightName = $request->input('lightweight_name', '');

        $data = $glendale->getModel3DViews($lightweightName);

        return $this->successData($data);
    }

    // 模型合并保存
    public function combine(Request $request)
    {
        $inputArr = $this->validate($request, [
            'name' => 'required',
            'library_id' => 'required',
            'data' => 'required|array',
            'data.*.bim_file_id' => 'required',
            'data.*.offset' => 'required',
            'data.*.rotate' => 'required',
        ]);

        $library = Library::query()->allowed()->findOrFail((int)$inputArr['library_id']);

        $bimCombine = BimCombine::create([
            'company_id' => Auth::user()->company_id,
            'created_by' => Auth::id(),
            'library_id' => $library->id,
            'name' => $inputArr['name'],
            'data' => $inputArr['data']
        ]);

        return new BimCombineResource($bimCombine);
    }

    //合模列表接口
    public function combinedList()
    {
        $bimCombines = BimCombine::query()
            ->allowed()
            ->latest('id')->paginate();

        return BimCombineResource::collection($bimCombines);
    }
}
